class CQiException(Exception):
    """
    A base class from which all other exceptions inherit.
    If you want to catch all errors that the CQi package might raise,
    catch this base exception.
    """


class Error(CQiException):
    # ERROR = 0x02
    pass


class ErrorGeneralError(Error):
    # ERROR_GENERAL_ERROR = 0x0201
    pass


class ErrorConnectRefused(Error):
    # ERROR_CONNECT_REFUSED = 0x0202
    pass


class ErrorUserAbort(Error):
    # ERROR_USER_ABORT = 0x0203
    pass


class ErrorSyntaxError(Error):
    # ERROR_SYNTAX_ERROR = 0x0204
    pass


class CLError(CQiException):
    # CL_ERROR = 0x04
    pass


class CLErrorNoSuchAttribute(CLError):
    # CL_ERROR_NO_SUCH_ATTRIBUTE = 0x0401
    # returned if CQi server couldn't open attribute
    pass


class CLErrorWrongAttributeType(CLError):
    # CL_ERROR_WRONG_ATTRIBUTE_TYPE = 0x0402
    # CDA_EATTTYPE
    pass


class CLErrorOutOfRange(CLError):
    # CL_ERROR_OUT_OF_RANGE = 0x0403
    # CDA_EIDORNG, CDA_EIDXORNG, CDA_EPOSORNG
    pass


class CLErrorRegex(CLError):
    # CL_ERROR_REGEX = 0x0404
    # CDA_EPATTERN (not used), CDA_EBADREGEX
    pass


class CLErrorCorpusAccess(CLError):
    # CL_ERROR_CORPUS_ACCESS = 0x0405
    # CDA_ENODATA
    pass


class CLErrorOutOfMemory(CLError):
    # CL_ERROR_OUT_OF_MEMORY = 0x0406
    # CDA_ENOMEM
    # this means the CQi server has run out of memory;
    # try discarding some other corpora and/or subcorpora
    pass


class CLErrorInternal(CLError):
    # CL_ERROR_INTERNAL = 0x0407
    # CDA_EOTHER, CDA_ENYI
    # this is the classical 'please contact technical support' error
    pass


class CQPError(CQiException):
    # CQP_ERROR = 0x05
    # CQP error messages yet to be defined
    pass


class CQPErrorGeneral(CQPError):
    # CQP_ERROR_GENERAL = 0x0501
    pass
    # CQP_ERROR_NO_SUCH_CORPUS = 0x0502


class CQPErrorInvalidField(CQPError):
    # CQP_ERROR_INVALID_FIELD = 0x0503
    pass


class CQPErrorOutOfRange(CQPError):
    # CQP_ERROR_OUT_OF_RANGE = 0x0504
    # various cases where a number is out of range
    pass
